## ------------------------------------------------------------------------
url_bdf_zip <- "https://www.biosemi.com/download/BDFtestfiles.zip"
temp <- tempfile()
download.file(url_bdf_zip, temp)
unzip(temp)
unlink(temp)

## ---- warning = FALSE, message = FALSE-----------------------------------
library(eegUtils)
library(dplyr)

bdf_filename <- "Newtest17-256.bdf"
bdf_data <- import_raw(bdf_filename)

## ------------------------------------------------------------------------
str(bdf_data)

## ------------------------------------------------------------------------
my_data <- bdf_data %>%
  select_elecs(c("A1", "A2"), keep = FALSE) %>% # remove channels
  reref_eeg(ref_chans = "average") %>% # re-reference
  iir_filt(low_freq = 0.1, high_freq = 40) %>% # band-pass filter
  epoch_data(255, c(-.2,.2)) # epoch: choose a trigger and time limits

## ------------------------------------------------------------------------
plot_butterfly(my_data, baseline = c(-.2, 0), time_lim = c(-.1, .2), legend = FALSE)

## ------------------------------------------------------------------------
plot_timecourse(my_data, electrode = "A3", baseline = c(-.2,0), time_lim = c(-.1, .2))

## ------------------------------------------------------------------------
erp_image(my_data, electrode = "A9")

